@@ -52,6 +52,7 @@ class GithubAccess(ResourceAccess):
     repoUrl: str
     ref: str
     type: AccessType
+    commit: typing.Optional[str]
 
     def __post_init__(self):
         parsed = self._normalise_and_parse_url()
@@ -97,6 +98,25 @@ class Label:
     value: typing.Union[str, int, float, bool, dict]
 
 
+_no_default = object()
+
+
+class FindLabelMixin:
+    def find_label(
+        self,
+        name: str,
+        default=_no_default,
+
+    ):
+        for label in self.labels:
+            if label.name == name:
+                return label
+        else:
+            if default is _no_default:
+                raise ValueError(f'no such label: {name=}')
+            return default
+
+
 class Provider(enum.Enum):
     '''
     internal: from repositoryContext-owner
@@ -113,7 +133,7 @@ class Metadata:
 
 
 @dc(frozen=True)
-class ComponentReference:
+class ComponentReference(FindLabelMixin):
     name: str
     componentName: str
     version: str
@@ -121,7 +141,7 @@ class ComponentReference:
 
 
 @dc(frozen=True)
-class Resource:
+class Resource(FindLabelMixin):
     name: str
     version: str
     type: ResourceType
@@ -143,7 +163,7 @@ class RepositoryContext:
 
 
 @dc
-class ComponentSource:
+class ComponentSource(FindLabelMixin):
     name: str
     access: typing.Union[
         GithubAccess,
@@ -153,7 +173,7 @@ class ComponentSource:
 
 
 @dc
-class Component:
+class Component(FindLabelMixin):
     name: str    # must be valid URL w/o schema
     version: str # relaxed semver
 
@@ -171,10 +191,6 @@ class Component:
             return None
         return self.repositoryContexts[-1]
 
-    # XXX rm asap - keep for backards-compat
-    localResources: typing.List[Resource] = dataclasses.field(default_factory=list)
-    externalResources: typing.List[Resource] = dataclasses.field(default_factory=list)
-
 
 @dc
 class ComponentDescriptor:
